@@ -4,7 +4,7 @@ I'll continue to update it with useful functions that I find myself reusing. The
 """
 
 # Version string
-__version__ = "1.3.0"
+__version__ = "1.3.1"
 
 
 
@@ -12,7 +12,7 @@ import itertools as it
 import numpy as np
 from . import data
 
-from typing import Any, List, Callable, Tuple
+from typing import Any, List, Callable, Tuple, Iterable
 
 
 def fdir(o: Any) -> List[str]:
